% A visual representation of a random walk. 
% Step sizes are fixed, but directions are random.

%Number of steps
N = 1e5;

%Fixed step size
s = 1;

%Fontsize and markersize
fsize = 18; msize = 10;

%Initilize x,y position vectors, starting from the origin.
x = zeros(1,N); y = zeros(1,N);

%Determine random walk
for n=2:N
    theta = 2*pi*rand;
    x(n) = x(n-1) + s*cos(theta); y(n) = y(n-1) + s*sin(theta);
end

%Plot random walk
plot(x,y,'b-','linewidth',0.1); hold on; 
plot( x(1),y(1),'g*','markersize',msize );
plot( x(end),y(end),'r*','markersize',msize );
set(gca,'fontsize',fsize); grid on;
xlabel('x'); ylabel('y'); title( ['Random walk. Step size = ',num2str(s)] );

%Print a PNG file of the random walk
print( gcf, 'random walk.png','-dpng','-r300' ); close(gcf);

%End of code