% A visual representation of a random walk. Step sizes are fixed, but
% directions are random. This development of random_walk uses the random
% walk implemented in a function, and therefore enables an overlay of
% multiple random walks (of random colours).
%
% LAST UPDATED by Andy French May 2021
function random_walks

P = 42;  %Numbers of random walks
N = 5000;  %Number of steps
s = 1;  %Fixed step size
fsize = 18; %Graph fontsize

%Initialize axes and then plot random walks
axes('nextplot','add','fontsize',fsize);
for n=1:P
    [x,y] = randomwalk(N,s); 
    RGB = rand(1,3); plot(x,y,'-','color',RGB);
end
xlabel('x'); ylabel('y'); title( ['Random walk. Step size = ',num2str(s)] );
grid on; axis equal; box on;

%Print a PNG file of the random walk
filename = ['random walks ',strrep(datestr(now),':','-'),'.png'];
print( gcf, filename,'-dpng','-r300' );
close(gcf);

%%

%Random walk generator
function [x,y] = randomwalk(N,s)
x = zeros(1,N); y = zeros(1,N);
for n=2:N
    theta = 2*pi*rand;
    x(n) = x(n-1) + s*cos(theta); y(n) = y(n-1) + s*sin(theta);
end

%End of code