% A visual representation of a random walk. Step sizes are fixed, but
% directions are random. This development of random_walk uses the random
% walk implemented in a function, and therefore enables an overlay of
% multiple random walks (of random colours).
%
% LAST UPDATED by Andy French May 2021
function random_walks_vectorized

P = 42;  %Numbers of random walks
N = 8000;  %Number of steps
s = 1;  %Fixed step size
fsize = 18; %Graph fontsize

%Initialize axes and then plot random walks
axes('nextplot','add','fontsize',fsize);
[x,y] = randomwalk(P,N,s);
RGB = rand(P,3);
for n=1:P
     plot( x(:,n),y(:,n),'-','color',RGB(n,:) );
end
xlabel('x'); ylabel('y'); title( ['Random walk. Step size = ',num2str(s)] );
grid on; axis equal; box on;

%Print a PNG file of the random walk
filename = ['random walks ',strrep(datestr(now),':','-'),'.png'];
print( gcf, filename,'-dpng','-r300' );
close(gcf);

%%

%Random walk generator. Columns of x,y are P different random walks.
function [x,y] = randomwalk(P,N,s)
theta = 2*pi*rand(N-1,P);
x = cumsum(s*cos(theta),1); y = cumsum(s*sin(theta),1);
x = [ zeros(1,P); x ]; y = [ zeros(1,P); y ];

%End of code